.. _spkg_pybtex:

pybtex: A BibTeX-compatible bibliography processor in Python
============================================================

Description
-----------

A BibTeX-compatible bibliography processor in Python

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/pybtex/



Type
----

optional


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)

Version Information
-------------------

requirements.txt::

    pybtex

Equivalent System Packages
--------------------------

.. tab:: conda-forge:

   .. CODE-BLOCK:: bash

       $ conda install pybtex

.. tab:: Fedora/Redhat/CentOS:

   .. CODE-BLOCK:: bash

       $ sudo dnf install python3-pybtex

.. tab:: MacPorts:

   .. CODE-BLOCK:: bash

       $ sudo port install py-pybtex

.. tab:: openSUSE:

   .. CODE-BLOCK:: bash

       $ sudo zypper install python3\$\{PYTHON_MINOR\}-pybtex

# See https://repology.org/project/python:pybtex/versions

If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then ``./configure`` will check if the system package can be used.
